@@ -599,9 +599,7 @@ def import_complete(self, result_lst, importqueue_pk):
     """
     
     iq = ImportQueue.objects.get(pk=importqueue_pk)
-    des = iq.batch.destination
-    
-    
+        
     if all(r.ready() for r in itertools.chain(*result_lst)):
         if all(r.successful() for r in itertools.chain(*result_lst)):
             iq.success()
@@ -960,9 +958,10 @@ def pg_stage(self, stagingqueue_pk):
                 # set it to None regardless of availability
                 tbl_dte_source = None
             else:
-                # we need a dte_source
+                # we would really prefer a dte_source
                 if stg_q.dte_input is None or stg_q.dte_input.category != 'DAYSTOEVENT_SOURCE':
-                    raise Exception("Must provide a DAYSTOEVENT_SOURCE staging table for CORE_SOURCE tables that lack daystoevent and visitlink columns.")
+                    logger.warning("CORE_SOURCE StagingTable {src} lacks daystoevent and visitlink columns, but no DAYSTOEVENT_SOURCE table was provided as dte_input or the provided input is not of category DAYSTOEVENT_SOURCE. Table generation will proceed, but no revisit analysis will be possible (CORE_PROCESSED table will lack daystoevent and visitlink columns).")
+                    tbl_dte_source = None
                 else:
                     # grab that table info
                     tbl_dte_source = stg_q.dte_input.name
@@ -1006,7 +1005,6 @@ def pg_stage(self, stagingqueue_pk):
                     ON tbl_core_source.{ahal_join_field} = tbl_ahal_source.{ahal_join_field}
                     """.format(tbl_ahal_source=tbl_ahal_source, ahal_join_field=ahal_join_field)
             
-            # TODO: SEVERITY
             if tbl_severity is not None:
                 # skip columns in omit_from_right (pk fields and CORE_SOURCE fields)
                 
@@ -1025,7 +1023,13 @@ def pg_stage(self, stagingqueue_pk):
                 # and prepare JOIN them
                 
                 for f in dx_pr_grps_cols:
-                    if f.upper() not in uflag_names and f.lower() not in omit_from_right:
+                    # old way, where dx_pr_grps deferred to uflags
+                    #if f.upper() not in uflag_names and f.lower() not in omit_from_right:
+                    #    select_items.append('tbl_dx_pr_grps.{f} AS {f}'.format(f=f))
+                    # new way, where uflags defers to dx_pr_grps
+                    # due to truncation, especially in available pr and prccs, the provided
+                    # uflags from HCUP cannot be completely recreated with source data
+                    if f.lower() not in omit_from_right:
                         select_items.append('tbl_dx_pr_grps.{f} AS {f}'.format(f=f))
                         
                 jsql += """
@@ -1038,14 +1042,13 @@ def pg_stage(self, stagingqueue_pk):
                 # in pyhcup.default_uflaggers(), and prepare them as JOIN clauses
                 
                 for f in uflag_names:
-                    select_items.append('tbl_{flag_name}.value AS {flag_name}'.format(flag_name=f))
-                    jsql += """
-                        LEFT JOIN {tbl_uflags} AS tbl_{flag_name}
-                        ON tbl_{flag_name}.name = '{flag_name}' AND
-                            tbl_core_source.key = tbl_{flag_name}.key
-                        """.format(tbl_uflags=tbl_uflags, flag_name=f)
-            
-            # TODO: DX_PR_GRPS
+                    if tbl_dx_pr_grps is None or f.lower() not in dx_pr_grps_cols:
+                        select_items.append('tbl_{flag_name}.value AS {flag_name}'.format(flag_name=f))
+                        jsql += """
+                            LEFT JOIN {tbl_uflags} AS tbl_{flag_name}
+                            ON tbl_{flag_name}.name = '{flag_name}' AND
+                                tbl_core_source.key = tbl_{flag_name}.key
+                            """.format(tbl_uflags=tbl_uflags, flag_name=f)
             
             # concat everything into a stonking huge SQL statement
             full_sql = 'CREATE TABLE {output_tbl} AS\nSELECT {selects}\nFROM {tbl_core_source} AS tbl_core_source {joins}' \
@@ -1067,6 +1070,9 @@ def pg_stage(self, stagingqueue_pk):
         staged.wip = False
         staged.save()
         
+        # save a reference to the StagingTable in the StagingQueue object as output
+        stg_q.stg_output = staged
+        stg_q.save()
         stg_q.success('StagingTable %s (pk %s) updated as non-WIP and %s rows' % (staged.name, staged.pk, staged.records))
 
         return True
