@@ -33,12 +33,14 @@ stbatch_patterns = patterns('',
 
 tbl_patterns = patterns('',
     url(r'(?P<obj_id>\d+)/$', obj_detail, {'obj_type': 'StagingTable'}, name='tbl_detail'),
-    url(r'$', obj_inventory, {'obj_type': 'StagingTable'}, name='tbl_inv'),
-    url(r'(?P<category>[A-Z_]+|all)/(?P<year>[0-9]{4}|all)/(?P<state_abbr>[A-Z]{2}|all)/$',
+    #url(r'(?P<year>\d+|all)/(?P<state_abbr>[A-Z]{2}|all)/$', obj_inventory, {'obj_type': 'StagingTable'}, name='tbl_inv'),
+    #url(r'(?P<category>[A-Z_]+|all)/(?P<year>[0-9]{4}|all)/(?P<state_abbr>[A-Z]{2}|all)/$',
+    url(r'(?P<year>[0-9]{4}|all)/(?P<state_abbr>[A-Z]{2}|all)/$',
         obj_inventory,
         {'obj_type': 'StagingTable'},
         name='tbl-inventory-filtered'
         ),
+    url(r'$', obj_inventory, {'obj_type': 'StagingTable'}, name='tbl_inv'),
     #url(r'unprocessed_batch/$', 'create_batch_from_unprocessed'),
 )
 
