@@ -252,12 +252,41 @@ def obj_inventory(request, obj_type, *args, **kwargs):
         template = 'stg_inv.html'
     
     elif obj_type == 'StagingTable':
-        stt = StagingTable.objects.all()
+        stt = StagingTable.objects.all().order_by('category', '-name')
+        
         context = {
-            'objects': stt,
             'title': "StagingTable Inventory"
         }
-        template = 'stg_inv.html'
+        
+        if ('state_abbr' in kwargs and
+            kwargs['state_abbr'] != 'all'):
+            st = kwargs['state_abbr']
+            context['state_abbr'] = st
+            stt = filter(lambda x: x.state == st, stt)
+        else:
+            context['state_abbr'] = 'all'
+        
+        if ('year' in kwargs and
+            kwargs['year'] != 'all'):
+            yr = kwargs['year']
+            context['year'] = yr
+            stt = filter(lambda x: x.year == int(yr), stt)
+        else:
+            context['year'] = 'all'
+        
+        stt_yr_sorted = sorted(
+            stt,
+            lambda x, y: cmp(x.year, y.year)
+        )
+        
+        stt_styr_sorted = sorted(
+            stt_yr_sorted,
+            lambda x, y: cmp(x.state.lower(), y.state.lower())
+        )
+        
+        context['objects'] = stt_styr_sorted
+        
+        template = 'stg_inv_tbl.html'
     
     return render(request, template, context)
 
